@@ -2,6 +2,9 @@
 alac 78
 """
 
+import warnings
+warnings.filterwarnings('ignore')
+import fitz
 import glob
 import inspect
 import math
@@ -10,26 +13,21 @@ import re
 import sys
 import datetime
 import time
-import warnings
-import PyPDF2
 import click
 import numpy as np
 import pandas as pd
 import selenium
-from tqdm.autonotebook import tqdm
+from tqdm.auto import tqdm
 from selenium import webdriver
 from selenium.webdriver.common.by import By
 from selenium.webdriver.support.ui import Select
 from selenium.webdriver.chrome.options import Options
 
-import logging
-logger = logging.getLogger("PyPDF2")
-logger.setLevel(logging.ERROR)
 
 pd.set_option("mode.chained_assignment", None)
 pd.set_option("display.notebook_repr_html", True)
 pd.set_option('display.expand_frame_repr', False) 
-pd.set_option('display.max_rows', 100)
+pd.set_option('display.min_rows', 50)
 pd.set_option('compute.use_bottleneck', True)
 pd.set_option('compute.use_numexpr', True)
 pd.set_option('display.max_categories', 16)
@@ -37,7 +35,6 @@ pd.set_option('display.precision',2)
 
 
 tqdm.pandas()
-warnings.filterwarnings('ignore')
 
 
 ## CONFIG
@@ -391,12 +388,6 @@ def set(inputs, outputs=None, count=0, table='', overwrite=False, log=True, dedu
    if append:
       overwrite = True
 
-   if not debug:
-      sys.tracebacklimit = 0
-      warnings.filterwarnings('ignore')
-   else:
-      sys.tracebacklimit = 10
-
    # DEDUPE
    content_len = len(inputs.QUEUE)
    if dedupe and not fetch:
@@ -832,7 +823,7 @@ def map(conf, *args, bar=True, names=[]):
             else:
                column_getters.Name[i] = str(x.__name__).replace("get","").upper()
          except:
-            column_getters.Name[i] = str(x).replace("get","").upper()
+            column_getters.Name[i] = str(x.__name__).replace("get","").upper()
          column_getters.Method[i] = x
 
    for i, x in enumerate(args):
@@ -1396,39 +1387,24 @@ def charges(conf, multi=False):
 
 ## GETTERS
 
-def getPDFText(path: str) -> str:
-   """Returns PyPDF2 extract_text() outputs for all pages from path
-   
-   Args:
-      path (str): Description
-   
-   Returns:
-      str: Description
-   """
-   text = ""
+
+def getPDFText(path) -> str:
    try:
-      pdf = PyPDF2.PdfReader(path)
-      for pg in pdf.pages:
-         text += pg.extract_text()
+      doc = fitz.open(path)
    except:
-      text = ""
+      return ''
+   text = ''
+   for pg in doc:
+      text += ' \n '.join(x[4].replace("\n"," ") for x in pg.get_text(option='blocks'))
+   text = re.sub(r'(<image\:.+?>)','',text).strip()
    return text
 
+
 def getCaseNumber(text: str):
-   """Returns full case number with county number prefix from case text
-   
-   Args:
-      text (str): Description
-   
-   Returns:
-      TYPE: Description
-   """
-   try:
-      county: str = re.search(r'(?:County\: )(\d{2})(?:Case)', str(text)).group(1).strip()
-      case_num: str = county + "-" + re.search(r'(\w{2}\-\d{4}-\d{6}.\d{2})', str(text)).group(1).strip()
-      return case_num
-   except (IndexError, AttributeError):
-      return ""
+   county = re.search(r'(?:County\: )(\d{2})', text).group(1).strip()
+   case_num = re.search(r'(\w{2}\-\d{4}-\d{6}\.\d{2})', str(text)).group().strip()
+   return county + "-" + case_num
+
 
 def getName(text: str):
    """Returns name from case text
@@ -1500,11 +1476,11 @@ def getAddress(text: str):
    except (IndexError, AttributeError):
       zip_code = ""
    try:
-      city = re.search(r'(City\: )(.*)(State\: )(.*)', str(text), re.MULTILINE).group(2).strip()
+      city = re.search(r'(?:City\:)(.+?)(?:State)', str(text)).group().strip()
    except (IndexError, AttributeError):
       city = ""
    try:
-      state = re.search(r'(?:City\: ).*(?:State\: ).*', str(text), re.MULTILINE).group(4).strip()
+      state = re.search(r'(State\:\s+?[A-Z]{2})', text).group().strip()
    except (IndexError, AttributeError):
       state = ""
    address = street_addr + " " + city + ", " + state + " " + zip_code
@@ -1583,8 +1559,8 @@ def getCaseInfo(text: str):
    sex = ""
 
    try:
-      county: str = re.search(r'(?:County\: )(\d{2})(?:Case)', str(text)).group(1).strip()
-      case_num: str = county + "-" + re.search(r'(\w{2}\-\d{4}-\d{6}.\d{2})', str(text)).group(1).strip()
+      county: str = re.search(r'(?:County\: )(\d{2})', str(text)).group(1).strip()
+      case_num: str = county + "-" + re.search(r'(\w{2}\-\d{4}-\d{6}\.\d{2})', str(text)).group(1).strip()
    except (IndexError, AttributeError):
       pass
 
@@ -1632,7 +1608,7 @@ def getCaseInfo(text: str):
    except (IndexError, AttributeError):
       city = ""
    try:
-      state = re.search(r'(?:City\: ).*(?:State\: ).*', str(text), re.MULTILINE).group(4).strip()
+      state = re.search(r'(?:City\: )(.*)(?:State\: )(.*)', str(text), re.MULTILINE).group(2).strip()
    except (IndexError, AttributeError):
       state = ""
 
@@ -2167,9 +2143,10 @@ def party_search(driver, name = "", party_type = "", ssn="", dob="", county="",
    except selenium.common.exceptions.NoSuchElementException:
       if debug:
          print("""NoSuchElementException on alac.py 2173: party_name_box = driver.find_element(by=By.NAME, value="ctl00$ContentPlaceHolder1$txtName")""")
-      time.sleep(10)
-      login(driver,cID=cID,uID=uID,pwd=pwd)
-      driver.implicitly_wait(1)
+      if driver.current_url == "https://v2.alacourt.com/frmlogin.aspx":
+         time.sleep(10)
+         login(driver,cID=cID,uID=uID,pwd=pwd)
+         driver.implicitly_wait(1)
       driver.get("https:v2.alacourt.com/frmIndexSearchForm.aspx")
 
       if not no_log:
@@ -2295,19 +2272,19 @@ def downloadPDF(driver, url, no_log=False, cID="", uID="", pwd="", speed=2):
    Deleted Parameters:
       speed (int, optional): fetch rate multiplier
    """
-   if driver.current_url == "https://v2.alacourt.com/frmlogin.aspx":
-      login(driver, cID, uID, pwd, speed, no_log)
+   if driver.current_url == "https://v2.alacourt.com/frmlogin.aspx" and cID != "" and uID != "" and pwd != "":
+      login(driver,cID=cID,uID=uID,pwd=pwd)
    a = driver.get(url)
    driver.implicitly_wait(0.5)
 
 
-def login(driver, cID, username="", uID="", pwd="", speed=1, no_log=False, path=""):
+def login(driver, cID, uID="", pwd="", speed=1, no_log=False, path=""):
    """Login to Alacourt.com using (driver) and auth (cID, username, pwd) at (speed) for browser download to directory at (path)
    
    Args:
       driver (WebDriver): Google Chrome selenium.WebDriver() object
       cID (str): Alacourt.com Customer ID
-      username (str): Alacourt.com User ID
+      uID (str): Alacourt.com User ID
       pwd (str): Alacourt.com Password
       speed (TYPE): fetch rate multiplier
       no_log (bool, optional): Do not print logs
@@ -2344,7 +2321,7 @@ def login(driver, cID, username="", uID="", pwd="", speed=1, no_log=False, path=
    login_button = driver.find_element(by=By.ID, value="ContentPlaceHolder_btLogin")
 
    cID_box.send_keys(cID)
-   username_box.send_keys(username)
+   username_box.send_keys(uID)
    pwd_box.send_keys(pwd)
 
    driver.implicitly_wait(1)
